@@ -11,9 +11,6 @@ BOT_NAME = 'example_project'
 SPIDER_MODULES = ['example_project.spiders']
 NEWSPIDER_MODULE = 'example_project.spiders'
 
-# Crawl responsibly by identifying yourself (and your website) on the user-agent
-#USER_AGENT = 'example_project (+http://www.yourdomain.com)'
-
 import os
 if os.environ.get("SENTRY_DSN", None) is None:
     import sys
@@ -23,13 +20,7 @@ if os.environ.get("SENTRY_DSN", None) is None:
 # log into sentry
 SENTRY_DSN = os.environ["SENTRY_DSN"]  # << set your sentry_dsn here >> 
 
-import scrapy_sentry
-scrapy_sentry.init(SENTRY_DSN)
-
-SPIDER_MIDDLEWARES = {
-    'scrapy_sentry.middlewares.SentryMiddleware': 10,
+EXTENSIONS = {
+    'scrapy_sentry.extensions.Errors':10,
 }
 
-DOWNLOADER_MIDDLEWARES = {
-    'scrapy_sentry.middlewares.SentryMiddleware': 10,
-}
\ No newline at end of file
